@@ -14,8 +14,6 @@
 #include <QDialogButtonBox>
 #include <QIcon>
 
-#include "ctcron.h"
-#include "cthost.h"
 #include "ctvariable.h"
 
 #include "crontabWidget.h"
@@ -215,3 +213,5 @@ void VariableEditorDialog::slotWizard()
         mOkButton->setEnabled(true);
     }
 }
+
+#include "moc_variableEditorDialog.cpp"
